JDevlieghere created this revision.
JDevlieghere added reviewers: labath, jingham.
JDevlieghere requested review of this revision.

Split TestCxxChar8_t into two parts: one that check reading variables without a 
process and another part with. This allows us to skip the former on Apple 
Silicon, where lack of support for chained fix-ups causes the test to fail.


https://reviews.llvm.org/D114819

Files:
  lldb/test/API/lang/cpp/char8_t/TestCxxChar8_t.py


Index: lldb/test/API/lang/cpp/char8_t/TestCxxChar8_t.py
===================================================================
--- lldb/test/API/lang/cpp/char8_t/TestCxxChar8_t.py
+++ lldb/test/API/lang/cpp/char8_t/TestCxxChar8_t.py
@@ -15,13 +15,12 @@
     mydir = TestBase.compute_mydir(__file__)
 
     @skipIf(compiler="clang", compiler_version=['<', '7.0'])
-    def test(self):
-        """Test that C++ supports char8_t correctly."""
+    @expectedFailureDarwin(archs=["arm64", "arm64e"]) # 
<rdar://problem/37773624>
+    def test_without_process(self):
+        """Test that C++ supports char8_t without a running process."""
         self.build()
-
         lldbutil.run_to_breakpoint_make_target(self)
 
-        # Make sure the variables can be printed without a running process.
         self.expect("target variable a", substrs=["char8_t", "0x61 u8'a'"])
         self.expect("target variable ab",
                 substrs=["const char8_t *", 'u8"你好"'])
@@ -29,9 +28,17 @@
 
         self.expect_expr("a", result_type="char8_t", result_summary="0x61 
u8'a'")
         self.expect_expr("ab", result_type="const char8_t *", 
result_summary='u8"你好"')
+
         # FIXME: This should work too.
         self.expect("expr abc", substrs=['u8"你好"'], matching=False)
 
+
+    @skipIf(compiler="clang", compiler_version=['<', '7.0'])
+    def test_with_process(self):
+        """Test that C++ supports char8_t with a running process."""
+        self.build()
+        lldbutil.run_to_breakpoint_make_target(self)
+
         lldbutil.run_break_set_by_source_regexp(self, "// break here", "-f 
main.cpp")
         self.runCmd("run")
 


Index: lldb/test/API/lang/cpp/char8_t/TestCxxChar8_t.py
===================================================================
--- lldb/test/API/lang/cpp/char8_t/TestCxxChar8_t.py
+++ lldb/test/API/lang/cpp/char8_t/TestCxxChar8_t.py
@@ -15,13 +15,12 @@
     mydir = TestBase.compute_mydir(__file__)
 
     @skipIf(compiler="clang", compiler_version=['<', '7.0'])
-    def test(self):
-        """Test that C++ supports char8_t correctly."""
+    @expectedFailureDarwin(archs=["arm64", "arm64e"]) # <rdar://problem/37773624>
+    def test_without_process(self):
+        """Test that C++ supports char8_t without a running process."""
         self.build()
-
         lldbutil.run_to_breakpoint_make_target(self)
 
-        # Make sure the variables can be printed without a running process.
         self.expect("target variable a", substrs=["char8_t", "0x61 u8'a'"])
         self.expect("target variable ab",
                 substrs=["const char8_t *", 'u8"你好"'])
@@ -29,9 +28,17 @@
 
         self.expect_expr("a", result_type="char8_t", result_summary="0x61 u8'a'")
         self.expect_expr("ab", result_type="const char8_t *", result_summary='u8"你好"')
+
         # FIXME: This should work too.
         self.expect("expr abc", substrs=['u8"你好"'], matching=False)
 
+
+    @skipIf(compiler="clang", compiler_version=['<', '7.0'])
+    def test_with_process(self):
+        """Test that C++ supports char8_t with a running process."""
+        self.build()
+        lldbutil.run_to_breakpoint_make_target(self)
+
         lldbutil.run_break_set_by_source_regexp(self, "// break here", "-f main.cpp")
         self.runCmd("run")
 
_______________________________________________
lldb-commits mailing list
lldb-commits@lists.llvm.org
https://lists.llvm.org/cgi-bin/mailman/listinfo/lldb-commits

Reply via email to